import { JSONSchema7, JSONSchema7TypeName } from "json-schema";
import { DPMConfiguration } from "./main";
export declare enum CountPrecision {
    EXACT = "EXACT",
    APPROXIMATE = "APPROXIMATE",
    GREATER_THAN = "GREATER_THAN"
}
export declare enum PublishMethod {
    SCHEMA_ONLY = "SCHEMA_ONLY",
    SCHEMA_AND_DATA = "SCHEMA_AND_DATA",
    SCHEMA_PROXY_DATA = "SCHEMA_PROXY_DATA"
}
export interface StreamStats {
    byteCount?: number;
    byteCountPrecision?: CountPrecision;
    inspectedCount: number;
    recordCount?: number;
    recordCountPrecision?: CountPrecision;
}
export interface RegistryReference {
    url: string;
    catalogSlug: string;
    publishMethod: PublishMethod;
}
export interface StreamSet {
    slug: string;
    configuration: DPMConfiguration;
    schemaTitles: string[];
    lastUpdateHash?: string;
    streamStats: StreamStats;
}
export interface Source {
    type: string;
    slug: string;
    connectionConfiguration: DPMConfiguration;
    credentialsIdentifier?: string;
    configuration?: DPMConfiguration;
    streamSets: StreamSet[];
}
export interface ContentLabel {
    label: string;
    hidden: boolean;
    appliedByContentDetector?: string;
    ocurrenceCount?: number;
    valuesTestedCount?: number;
}
export interface ValueTypeStatistics {
    valueType: JSONSchema7TypeName | "date";
    recordCount?: number;
    stringMaxLength?: number;
    stringMinLength?: number;
    numberMaxValue?: number;
    numberMinValue?: number;
    dateMaxValue?: Date;
    dateMinValue?: Date;
    stringOptions?: {
        [key: string]: number;
    };
    contentLabels?: ContentLabel[];
}
export declare type Properties = {
    [key: string]: Schema;
};
export declare type ValueTypes = {
    [key: string]: ValueTypeStatistics;
};
export interface MajorVersionIdentifier {
    registryUrl: string;
    catalogSlug: string;
    packageSlug: string;
    majorVersion: number;
}
export interface SchemaIdentifier extends MajorVersionIdentifier {
    schemaTitle: string;
}
export interface DerivedFrom {
    displayName: string;
    url?: string;
    schemaIdentifier?: SchemaIdentifier;
}
export interface Schema extends JSONSchema7 {
    description?: string;
    properties?: Properties;
    hidden?: boolean;
    unit?: string;
    recordsInspectedCount?: number;
    recordCount?: number;
    recordsNotPresent?: number;
    recordCountPrecision?: CountPrecision;
    valueTypes?: ValueTypes;
    sampleRecords?: {
        [key: string]: unknown;
    }[];
    derivedFromDescription?: string;
    derivedFrom?: DerivedFrom[];
}
export declare class PackageFile {
    $schema: string;
    canonical: boolean;
    modifiedProperties?: string[];
    packageSlug: string;
    displayName: string;
    description: string;
    sources: Source[];
    schemas: Schema[];
    version: string;
    generatedBy: string;
    updatedDate: Date;
    readmeFile?: string;
    readmeMarkdown?: string;
    licenseFile?: string;
    licenseMarkdown?: string;
    website?: string;
    contactEmail?: string;
    registries?: RegistryReference[];
}
