import { UpdateMethod } from "./DataHandlingUtil";
import { MajorVersionIdentifier, SchemaIdentifier } from "./main";
import { DPMRecord } from "./PackageUtil";
import { SinkState } from "./SinkState";
export interface SchemaRepositoryStreamIdentifier extends SchemaIdentifier {
    sourceType: string;
    sourceSlug: string;
    streamSetSlug: string;
    streamSlug: string;
}
export interface BatchRepositoryIdentifier extends SchemaRepositoryStreamIdentifier {
    batch: number;
}
export interface DataRecordContext {
    offset: number;
    record: DPMRecord;
}
export declare enum SocketEvent {
    READY = "ready",
    OPEN_FETCH_CHANNEL = "openFetchChannel",
    START_DATA_UPLOAD = "startDataUpload",
    SET_STREAM_ACTIVE_BATCHES = "setStreamActiveBatchesRequest",
    SCHEMA_INFO_REQUEST = "schemaInfoRequest",
    PACKAGE_VERSION_SINK_STATE_REQUEST = "packageVersionSinkStateRequest"
}
export declare enum SocketError {
    NOT_AUTHORIZED = "notAuthorized",
    NOT_FOUND = "notFound",
    NOT_VALID = "notValid",
    STREAM_LOCKED = "streamLocked",
    SERVER_ERROR = "serverError",
    NOT_STARTED = "streamProcessNotStarted"
}
export declare enum SocketResponseType {
    ERROR = "error",
    SCHEMA_INFO_RESPONSE = "schemaInfoResponse",
    START_DATA_UPLOAD_RESPONSE = "startDataUploadResponse",
    SET_STREAM_ACTIVE_BATCHES = "setStreamActiveBatchesResponse",
    OPEN_FETCH_CHANNEL_RESPONSE = "openFetchChannelResponse",
    PACKAGE_VERSION_SINK_STATE_RESPONSE = "packageVersionSinkStateResponse"
}
export interface Request {
    requestType: SocketEvent;
}
export interface Response {
    responseType: SocketResponseType;
}
export declare class ErrorResponse implements Response {
    message: string;
    errorType: SocketError;
    responseType: SocketResponseType;
    constructor(message: string, errorType: SocketError);
}
export declare class PackageSinkStateRequest implements Request {
    identifier: MajorVersionIdentifier;
    requestType: SocketEvent;
    constructor(identifier: MajorVersionIdentifier);
}
export declare class PackageSinkStateResponse implements Response {
    identifier: MajorVersionIdentifier;
    state: SinkState;
    responseType: SocketResponseType;
    constructor(identifier: MajorVersionIdentifier, state: SinkState);
}
export declare class PackageStreamsRequest implements Request {
    identifier: MajorVersionIdentifier;
    requestType: SocketEvent;
    constructor(identifier: MajorVersionIdentifier);
}
export interface BatchInfo {
    batchIdentifier: BatchRepositoryIdentifier;
    highestOffset: number;
    updatedAt: Date;
    updateMethod: UpdateMethod;
}
export interface BatchesBySchema {
    [schema: string]: BatchInfo[];
}
export declare class PackageStreamsResponse implements Response {
    identifier: MajorVersionIdentifier;
    batchesBySchema: BatchesBySchema;
    responseType: SocketResponseType;
    constructor(identifier: MajorVersionIdentifier, batchesBySchema: BatchesBySchema);
}
export declare class SetStreamActiveBatchesRequest implements Request {
    batchIdentifiers: BatchRepositoryIdentifier[];
    requestType: SocketEvent;
    constructor(batchIdentifiers: BatchRepositoryIdentifier[]);
}
export declare class SetStreamActiveBatchesResponse implements Response {
    batchIdentifiers: BatchRepositoryIdentifier[];
    responseType: SocketResponseType;
    constructor(batchIdentifiers: BatchRepositoryIdentifier[]);
}
export declare enum UploadRequestType {
    UPLOAD_DATA = "uploadData",
    UPLOAD_STOP = "uploadStop"
}
export declare enum UploadResponseType {
    UPLOAD_RESPONSE = "uploadResponse",
    UPLOAD_STOP_RESPONSE = "uploadStopResponse"
}
export interface UploadRequest {
    requestType: UploadRequestType;
}
export interface UploadResponse {
    responseType: UploadResponseType;
}
export declare class StartUploadRequest implements Request {
    schemaStreamIdentifier: SchemaRepositoryStreamIdentifier;
    newBatch: boolean;
    updateMethod: UpdateMethod;
    requestType: SocketEvent;
    constructor(schemaStreamIdentifier: SchemaRepositoryStreamIdentifier, newBatch: boolean, updateMethod: UpdateMethod);
}
export declare class StartUploadResponse implements Response {
    channelName: string;
    batchIdentifier: BatchRepositoryIdentifier;
    responseType: SocketResponseType;
    constructor(channelName: string, batchIdentifier: BatchRepositoryIdentifier);
}
export declare class UploadDataRequest implements UploadRequest {
    records: DataRecordContext[];
    requestType: UploadRequestType;
    constructor(records: DataRecordContext[]);
}
export declare class UploadDataResponse implements UploadResponse {
    responseType: UploadResponseType;
}
export declare class UploadStopRequest implements UploadRequest {
    requestType: UploadRequestType;
}
export declare class UploadStopResponse implements UploadResponse {
    responseType: UploadResponseType;
}
export declare class OpenFetchChannelRequest implements Request {
    batchIdentifier: BatchRepositoryIdentifier;
    requestType: SocketEvent;
    constructor(batchIdentifier: BatchRepositoryIdentifier);
}
export declare class OpenFetchChannelResponse implements Response {
    channelName: string;
    batchIdentifier: BatchRepositoryIdentifier;
    responseType: SocketResponseType;
    constructor(channelName: string, batchIdentifier: BatchRepositoryIdentifier);
}
export declare enum SocketFetchEvent {
    FETCH_DATA_ACKNOWLEDGE = "fetchDataAcknowledge",
    FETCH_DATA_END = "fetchDataEnd"
}
export declare enum FetchRequestType {
    START = "fetchDataStart",
    DATA = "data",
    STOP = "fetchDataStop"
}
export declare enum FetchResponseType {
    START_ACKNOWLEDGE = "startAcknowledge",
    DATA_ACKNOWLEDGE = "dataAcknowledge",
    STOP_ACKNOWLEDGE = "fetchDataStopAcknowledge"
}
export interface FetchRequest {
    requestType: FetchRequestType;
}
export interface FetchResponse {
    responseType: FetchResponseType;
}
export declare class StartFetchRequest implements FetchRequest {
    offset: number;
    requestType: FetchRequestType;
    constructor(offset: number);
}
export declare class StartFetchResponse implements FetchResponse {
    responseType: FetchResponseType;
}
export declare class DataSend implements FetchRequest {
    records: DataRecordContext[];
    requestType: FetchRequestType;
    constructor(records: DataRecordContext[]);
}
export declare class DataAcknowledge implements FetchResponse {
    responseType: FetchResponseType;
}
export declare class DataStop implements FetchRequest {
    requestType: FetchRequestType;
}
export declare class DataStopAcknowledge implements FetchResponse {
    responseType: FetchResponseType;
}
